@@ -14,7 +14,7 @@
 
 
 #' Get shortest path between points in list
-#' 
+#'
 #' @param sim sim list
 #' @noRd
 shortestPaths<- function(sim){
@@ -23,70 +23,72 @@ shortestPaths<- function(sim){
     #create a list of shortest paths
     paths <- unlist(lapply(sim$paths.list,
                            function(x){
-                             igraph::get.shortest.paths(sim$g, x[1], 
-                                                        x[2], out = "both") 
+                             igraph::shortest_paths(sim$g, x[1],
+                                                        x[2], out = "both")
                            } ))
-    
-    paths.v <- paths[grepl("vpath", names(paths))] 
-    
+
+    paths.v <- paths[grepl("vpath", names(paths))]
+
     # save the vertices for mapping
-    sim$paths.v <- rbind(data.table::data.table(paths.v), 
-                         sim$paths.v) 
-    
-    # use vertices to update cost raster to 0 at new roads need copy so old cost
+    sim$paths.v <- rbind(data.table::data.table(paths.v),
+                         sim$paths.v)
+
+    # use vertices to update weight raster to 0 at new roads need copy so old weight
     # available in pathsToLines
-    sim$costSurfaceNew <- sim$costSurface
-    sim$costSurfaceNew[unique(paths.v)] <- 0
-    
+    sim$weightRasterNew <- sim$weightRaster
+    sim$weightRasterNew[unique(paths.v)] <- 0
+
     # get edges for updating graph
     paths.e <- paths[grepl("epath", names(paths))]
-    
+
     rm(paths)
-    
-    # updates the cost(weight) associated with the edge that became a road
-    igraph::edge_attr(sim$g, 
-                      index = igraph::E(sim$g)[igraph::E(sim$g) %in% paths.e],
-                      name = "weight") <- 0.00001 
-    
+
+    # updates the weight associated with the edge that became a road
+    sim$g <- igraph::set_edge_attr(sim$g,
+                      index = igraph::E(sim$g)[paths.e],
+                      name = "weight", value = 0)
+
     rm(paths.e)
 
   }
   return(invisible(sim))
 }
 
-#' Get shortest path between points in list updating cost after each
-#' 
+#' Get shortest path between points in list updating weight after each
+#'
 #' @param sim sim list
 #' @noRd
-dynamicShortestPaths<- function(sim){
+iterativeShortestPaths<- function(sim){
   # finds the least cost paths between a list of two points
   if(!length(sim$paths.list) == 0){
     #create a list of shortest paths
     path.vs <- vector("list", length = length(sim$paths.list))
-    
+
     for (i in seq_along(sim$paths.list)) {
       path.list <- sim$paths.list[[i]]
-      path <- igraph::get.shortest.paths(sim$g, path.list[1], path.list[2], out = "both")
-      
+      path <- igraph::shortest_paths(sim$g, path.list[1], path.list[2], out = "both")
+
       path <- unlist(path)
-      
-      # update the cost(weight) associated with the edge that became a road
-      igraph::edge_attr(sim$g, 
-                        index = igraph::E(sim$g)[igraph::E(sim$g) %in% path[grepl("epath", names(path))]],
-                        name = "weight") <- 0.00001 
-      
+
+      # update the weight associated with the edge that became a road
+      path_edge_ind <- igraph::E(sim$g)[path[grepl("epath", names(path))]]
+
+      sim$g <- igraph::set_edge_attr(sim$g,
+                                     index = path_edge_ind,
+                                     name = "weight", value = 0)
+
       # get vertices
       path.vs[[i]] <- data.table::data.table(path[grepl("vpath", names(path))] )
     }
     paths.v <-  do.call(rbind, path.vs)
-    
-    # use vertices to update cost raster to 0 at new roads need copy so old cost
+
+    # use vertices to update weight raster to 0 at new roads need copy so old weight
     # available in pathsToLines
-    sim$costSurfaceNew <- sim$costSurface
-    sim$costSurfaceNew[unique(paths.v)$V1] <- 0
-    
+    sim$weightRasterNew <- sim$weightRaster
+    sim$weightRasterNew[unique(paths.v)$V1] <- 0
+
     sim$paths.v <- rbind(sim$paths.v, paths.v)
-    
+
   }
   return(invisible(sim))
 }
